@@ -1,4 +1,3 @@
-import functools
 import logging
 import traceback
 from logging.handlers import SysLogHandler
@@ -6,23 +5,22 @@ from typing import Any, Callable
 
 
 def logging_function(func: Callable[..., Any]) -> Callable[..., Any]:
-    @functools.wraps(func)
     def wrapper(*args: Any, **kwargs: Any) -> Any:
         logger = init_logger()
         value = None
         try:
             value = func(*args, **kwargs)
             if value is not None:
-                logger.info(f'Logging in {func.__name__} return value {value}')
+                logger.info(f'[INFO] Logging in {func.__name__} return value {value}')
         except Exception as error:
             logger.error(
-                f"Error in {func.__name__} with {error} traceback: {traceback.format_exc()}")
+                f'[ERROR] Error in {func.__name__} with {error} traceback: {traceback.format_exc()}')
         return value
 
     def init_logger():
-        host = "logs.papertrailapp.com"
+        host = 'logs.papertrailapp.com'
         port = 40259
-        logger = logging.getLogger("vicEscribano")
+        logger = logging.getLogger('playfilm-shared')
         logger.setLevel(logging.DEBUG)
         handler = SysLogHandler(address=(host, port))
         logger.addHandler(handler)
